pub fn deployment_auth_model_package_selection(
name: impl Into<String>,
) -> AuthModelPackageSelectionExpand description
Compatibility alias for callers that already refer to the deployment-selected package identity.
pub fn deployment_auth_model_package_selection(
name: impl Into<String>,
) -> AuthModelPackageSelectionCompatibility alias for callers that already refer to the deployment-selected package identity.